@@ -70,7 +70,12 @@ namespace encode
 
         EncoderParams *encodeParams = (EncoderParams *)params;
 
-        ENCODE_CHK_STATUS_RETURN(SetSequenceStructs());
+        // If new seq, need to set sequence structs
+        // If RATECONTROL_CQL, need to update quality and bitrate .etc
+        if (encodeParams->bNewSeq || m_basicFeature->m_av1SeqParams->RateControlMethod == RATECONTROL_CQL)
+        {
+            ENCODE_CHK_STATUS_RETURN(SetSequenceStructs());
+        }
 
         const auto& seqParams = *m_basicFeature->m_av1SeqParams;
 
@@ -80,6 +85,15 @@ namespace encode
             "Encode RateControl Method",
             m_rcMode,
             MediaUserSetting::Group::Sequence);
+        
+        ENCODE_CHK_NULL_RETURN(m_basicFeature->m_av1PicParams);
+        MediaUserSetting::Value outValue;
+        ReadUserSetting(
+            m_userSettingPtr,
+            outValue,
+            "Adaptive TU Enable",
+            MediaUserSetting::Group::Sequence);
+        m_basicFeature->m_av1PicParams->AdaptiveTUEnabled |= outValue.Get<uint8_t>(); 
 #endif
         return MOS_STATUS_SUCCESS;
     }
@@ -205,9 +219,13 @@ namespace encode
         dmem->UPD_CurWidth  = (uint16_t)m_basicFeature->m_oriFrameWidth;
         dmem->UPD_CurHeight = (uint16_t)m_basicFeature->m_oriFrameHeight;
         dmem->UPD_Asyn = 0;
-        dmem->UPD_EnableAdaptiveRounding = m_basicFeature->m_adaptiveRounding;
+        dmem->UPD_EnableAdaptiveRounding = m_basicFeature->m_roundingMethod;
+        dmem->UPD_AdaptiveTUEnabled = picParams->AdaptiveTUEnabled;
+        dmem->UPD_EnableDeltaQP = picParams->PicFlags.fields.EnableDeltaQP;
 
-        if (seqParams->GopRefDist == 8)
+        if (seqParams->GopRefDist == 16 && m_rcMode == RATECONTROL_CQL)
+            dmem->UPD_MaxBRCLevel = 4;
+        else if (seqParams->GopRefDist == 8)
             dmem->UPD_MaxBRCLevel = 3;
         else if (seqParams->GopRefDist == 4)
             dmem->UPD_MaxBRCLevel = 2;
@@ -216,13 +234,11 @@ namespace encode
         else
             dmem->UPD_MaxBRCLevel = 0;
 
-        bool bAllowedPyramid = seqParams->GopRefDist != 3;
-
         if (m_basicFeature->m_pictureCodingType == I_TYPE)
         {
             dmem->UPD_CurrFrameType = AV1_BRC_FRAME_TYPE_I;
         }
-        else if (seqParams->SeqFlags.fields.HierarchicalFlag && bAllowedPyramid)
+        else if (seqParams->SeqFlags.fields.HierarchicalFlag)
         {
             if (picParams->HierarchLevelPlus1 > 0)
             {
@@ -230,13 +246,15 @@ namespace encode
                     {1, AV1_BRC_FRAME_TYPE_P_OR_LB},
                     {2, AV1_BRC_FRAME_TYPE_B},
                     {3, AV1_BRC_FRAME_TYPE_B1},
-                    {4, AV1_BRC_FRAME_TYPE_B2}};
+                    {4, AV1_BRC_FRAME_TYPE_B2},
+                    {5, AV1_BRC_FRAME_TYPE_B3}};
                 dmem->UPD_CurrFrameType = hierchLevelPlus1_to_brclevel.count(picParams->HierarchLevelPlus1) ? hierchLevelPlus1_to_brclevel[picParams->HierarchLevelPlus1] : AV1_BRC_FRAME_TYPE_INVALID;
                 //Invalid HierarchLevelPlus1 or LBD frames at level 3 eror check.
                 if ((dmem->UPD_CurrFrameType == AV1_BRC_FRAME_TYPE_INVALID) ||
-                    (m_basicFeature->m_ref.IsLowDelay() && dmem->UPD_CurrFrameType == AV1_BRC_FRAME_TYPE_B2))
+                    (m_basicFeature->m_ref.IsLowDelay() && dmem->UPD_CurrFrameType == AV1_BRC_FRAME_TYPE_B2) ||
+                    (m_rcMode != RATECONTROL_CQL && dmem->UPD_CurrFrameType == AV1_BRC_FRAME_TYPE_B3))
                 {
-                    ENCODE_VERBOSEMESSAGE("AV1_BRC_FRAME_TYPE_INVALID or LBD picture doesn't support Level 4\n");
+                    ENCODE_VERBOSEMESSAGE("AV1_BRC_FRAME_TYPE_INVALID or LBD picture doesn't support Level 4, or AV1_BRC_FRAME_TYPE_B3 only supported in RATECONTROL_CQL mode\n");
                     dmem->UPD_CurrFrameType = AV1_BRC_FRAME_TYPE_B2;
                 }
             }
@@ -289,6 +307,8 @@ namespace encode
         dmem->UPD_VDEncCmd1Offset = m_slbData.vdencCmd1Offset;
         dmem->UPD_VDEncCmd2Offset = m_slbData.vdencCmd2Offset;
         dmem->UPD_AVPPicStateOffset = m_slbData.avpPicStateOffset;
+        dmem->UPD_VDEncTileSliceStateOffset = m_slbData.vdencTileSliceStateOffset;
+        dmem->UPD_TileNum = m_slbData.tileNum;
 
         // BA start
         dmem->UPD_LoopFilterParamsBitOffset      = (uint16_t)m_basicFeature->m_av1PicParams->LoopFilterParamsBitOffset;
@@ -313,6 +333,7 @@ namespace encode
         dmem->UPD_DisableCdfUpdate               = (m_basicFeature->m_av1PicParams->primary_ref_frame != av1PrimaryRefNone);
         dmem->UPD_EnableDMAForCdf                = 1;
         dmem->UPD_AdditionalHrdSizeByteCount     = 0 - m_basicFeature->m_av1PicParams->FrameSizeReducedInBytes;
+        dmem->UPD_PaletteOn                      = m_basicFeature->m_av1PicParams->PicFlags.fields.PaletteModeEnable;
 
         if (dmem->UPD_PAKPassNum == 1)
             m_curTargetFullness += m_inputbitsperframe;
@@ -322,6 +343,7 @@ namespace encode
             dmem->UPD_EnableCDEFUpdate = 0;
             dmem->UPD_EnableLFUpdate   = 0;
         }
+        dmem->UPD_QMatrixEnabled = m_basicFeature->m_av1PicParams->wQMatrixFlags.fields.using_qmatrix;
 
         return MOS_STATUS_SUCCESS;
     }
@@ -420,11 +442,15 @@ namespace encode
         return profileLevelMaxFrame;
     }
 
-    inline int32_t ComputeVDEncInitQPI(uint32_t width, uint32_t height, FRAMERATE frameRate, uint32_t targetBitRate, uint16_t gopPicSize, bool is10Bit, uint16_t n_p)
+    inline int32_t ComputeVDEncInitQPI(uint32_t width, uint32_t height, FRAMERATE frameRate, uint32_t targetBitRate, uint16_t gopPicSize, bool is10Bit, uint8_t chromaFormat, uint16_t n_p)
     {
         ENCODE_FUNC_CALL();
 
         uint32_t frameSize = ((width * height * 3) >> 1);
+        if (chromaFormat == AVP_CHROMA_FORMAT_YUV444)
+        {
+            frameSize *= 2;
+        }
         if (is10Bit)
         {
             frameSize = (frameSize * 10) >> 3;
@@ -501,6 +527,11 @@ namespace encode
                 dmem->INIT_GopB  = intraPeriod / BGOPSize;
                 dmem->INIT_GopB1 = (dmem->INIT_GopP + dmem->INIT_GopB == intraPeriod)? 0 : dmem->INIT_GopP * 2;
                 dmem->INIT_GopB2 = intraPeriod - dmem->INIT_GopP - dmem->INIT_GopB - dmem->INIT_GopB1;
+                if (m_rcMode == RATECONTROL_CQL && seqParams->GopRefDist == 16)
+                {
+                    dmem->INIT_GopB2 = (dmem->INIT_GopP + dmem->INIT_GopB + dmem->INIT_GopB1 == intraPeriod) ? 0 : dmem->INIT_GopB1 * 2;
+                    dmem->INIT_GopB3 = intraPeriod - dmem->INIT_GopP - dmem->INIT_GopB - dmem->INIT_GopB1 - dmem->INIT_GopB2;
+                }
             }
             else
             {
@@ -528,6 +559,10 @@ namespace encode
         MEMCPY_CONST(INIT_InstRateThreshP0, instRateThresholdP);
 #undef MEMCPY_CONST
 
+        if (dmem->INIT_FrameRateM == 0)
+        {
+            return MOS_STATUS_INVALID_PARAMETER;
+        }
         double inputBitsPerFrame = ((double)dmem->INIT_MaxRate * (double)dmem->INIT_FrameRateD) / (double)dmem->INIT_FrameRateM;
         double bpsRatio = inputBitsPerFrame / ((double)dmem->INIT_BufSize / brcSettings.devStdFPS);
         bpsRatio = MOS_CLAMP_MIN_MAX(bpsRatio, brcSettings.bpsRatioLow, brcSettings.bpsRatioHigh);
@@ -551,6 +586,7 @@ namespace encode
                 m_basicFeature->m_av1SeqParams->TargetBitRate[0],
                 m_basicFeature->m_av1SeqParams->GopPicSize,
                 m_basicFeature->m_is10Bit,
+                m_basicFeature->m_chromaFormat,
                 dmem->INIT_GopP);
 
         qpP = qpI + 20;
@@ -567,6 +603,11 @@ namespace encode
 
         dmem->INIT_SLIDINGWINDOW_ENABLE = seqParams->SlidingWindowSize != 0;
         dmem->INIT_SLIDINGWINDOW_SIZE = (uint8_t)seqParams->SlidingWindowSize;
+        if (dmem->INIT_SLIDINGWINDOW_ENABLE && seqParams->TargetBitRate[0] > 0)
+        {
+            dmem->INIT_OvershootCBR_pct = (uint16_t)(seqParams->MaxBitRatePerSlidingWindow * 100 / seqParams->TargetBitRate[0]);
+        }
+        dmem->INIT_GopPicSize = seqParams->GopPicSize;
 
         return MOS_STATUS_SUCCESS;
     }
@@ -576,7 +617,25 @@ namespace encode
         MOS_STATUS eStatus = MOS_STATUS_SUCCESS;
 
         ENCODE_FUNC_CALL();
-
+        
+        if (m_basicFeature->m_av1SeqParams->RateControlMethod == RATECONTROL_CQL)
+        {
+            const uint8_t ICQFactorLookup[52] = { 
+                0,  1,  1,  1,  1,  2,  3,  4,  6,  7,  9,  11, 13, 16, 18, 23,
+                26, 30, 34, 39, 46, 52, 59, 68, 77, 87, 98, 104,112,120,127,134,
+                142,149,157,164,171,178,186,193,200,207,213,219,225,230,235,240,
+                245,249,252,255 
+            };
+            
+            uint32_t TargetBitRate                                     = m_basicFeature->m_frameWidth * m_basicFeature->m_frameHeight * 8 / 1000;
+            m_basicFeature->m_av1SeqParams->ICQQualityFactor           = ICQFactorLookup[m_basicFeature->m_av1SeqParams->ICQQualityFactor];
+            m_basicFeature->m_av1SeqParams->TargetBitRate[0]           = TargetBitRate;
+            m_basicFeature->m_av1SeqParams->MaxBitRate                 = (TargetBitRate << 4) / 10;
+            m_basicFeature->m_av1SeqParams->MinBitRate                 = 0;
+            m_basicFeature->m_av1SeqParams->InitVBVBufferFullnessInBit = 8000 * (TargetBitRate << 3) / 10;
+            m_basicFeature->m_av1SeqParams->VBVBufferSizeInBit         = 8000 * (TargetBitRate << 1);
+        }
+        
         m_brcEnabled = IsRateControlBrc(m_basicFeature->m_av1SeqParams->RateControlMethod);
 
         m_brcInit = m_brcEnabled && m_basicFeature->m_resolutionChanged;
